==> haskell-hslua-module-doclayout-1.1.1.2-13.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-doclayout.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-doclayout
version:              1.1.1.2
visibility:           public
id:                   hslua-module-doclayout-1.1.1.2-2hEIwHnTyKKFKaGOWZfhav
key:                  hslua-module-doclayout-1.1.1.2-2hEIwHnTyKKFKaGOWZfhav
license:              MIT
copyright:            © 2020-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua-module-doclayout
synopsis:             Lua module wrapping Text.DocLayout.
description:          Lua module wrapping @Text.DocLayout@.
category:             Foreign
abi:                  fbf335de389abbf31084a803b486e443
exposed:              True
exposed-modules:      HsLua.Module.DocLayout
import-dirs:
    /usr/lib/ghc-9.6.6/site-local/hslua-module-doclayout-1.1.1.2

library-dirs:
    /usr/lib/ghc-9.6.6/site-local/hslua-module-doclayout-1.1.1.2

library-dirs-static:
    /usr/lib/ghc-9.6.6/site-local/hslua-module-doclayout-1.1.1.2

dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-doclayout
hs-libraries:         HShslua-module-doclayout-1.1.1.2-2hEIwHnTyKKFKaGOWZfhav
depends:
    base-4.18.2.1 doclayout-0.5-G2Wm2VuIsgJ2QywWYn7p6r
    hslua-2.3.0-AIYoFrxEfNp4l0Epo8ciVq text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-doclayout/html/hslua-module-doclayout.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-doclayout/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hslua-module-doclayout-1.2.0-2-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-hslua-module-doclayout.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hslua-module-doclayout
version:              1.2.0
visibility:           public
id:                   hslua-module-doclayout-1.2.0-CGrFw35ApIf5eXoqiHdAkP
key:                  hslua-module-doclayout-1.2.0-CGrFw35ApIf5eXoqiHdAkP
license:              MIT
copyright:            © 2020-2024 Albert Krewinkel
maintainer:           Albert Krewinkel <albert@zeitkraut.de>
author:               Albert Krewinkel
homepage:             https://github.com/hslua/hslua-module-doclayout
synopsis:             Lua module wrapping Text.DocLayout.
description:          Lua module wrapping @Text.DocLayout@.
category:             Foreign
abi:                  c855f1f284560214bd75f5f400f1578f
exposed:              True
exposed-modules:      HsLua.Module.DocLayout
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hslua-module-doclayout-1.2.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hslua-module-doclayout-1.2.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hslua-module-doclayout-1.2.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hslua-module-doclayout
hs-libraries:         HShslua-module-doclayout-1.2.0-CGrFw35ApIf5eXoqiHdAkP
depends:
    base-4.18.2.1 doclayout-0.5-9EZxKgaNTpvH3oLmqoAtl2
    hslua-2.3.0-G91elmK0fcG86VJ87ZrTOH text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-hslua-module-doclayout/html/hslua-module-doclayout.haddock

haddock-html:         /usr/share/doc/haskell-hslua-module-doclayout/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
